@@ -1,6 +1,7 @@
 # !/usr/bin/python
 # coding=utf-8
 import sys
+import re
 from functools import partial
 from PySide2 import QtCore, QtGui, QtWidgets
 from pythontk import File
@@ -56,10 +57,9 @@ class MainWindow(QtWidgets.QMainWindow, Attributes):
 		self.sb = switchboard_instance
 		self.name = File.formatPath(file, 'name')
 		setattr(self.sb, self.name, self)
-		if '#' in self.name: #set an alternate attribute name with legal characters.
-			legal_name = self.name.replace('#', '_')
-			if not hasattr(self.sb, legal_name):
-				setattr(self.sb, legal_name, self)
+		legal_name = re.sub(r'[^0-9a-zA-Z]', '_', self.name)
+		if self.name != legal_name: #if the name contains illegal chars; set an alternate attribute name with legal characters.
+			setattr(self.sb, legal_name, self)
 
 		self.path = File.formatPath(file, 'path')
 		self.level = self.sb._getUiLevelFromDir(file)
